==> haskell-regex-tdfa-1.3.2.3-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-tdfa
version:              1.3.2.3
visibility:           public
id:                   regex-tdfa-1.3.2.3-2vpgF9jiCYzHaZRZi6jkOP
key:                  regex-tdfa-1.3.2.3-2vpgF9jiCYzHaZRZi6jkOP
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2009, Christopher Kuklewicz
maintainer:           Andreas Abel
author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:
    Pure Haskell Tagged DFA Backend for "Text.Regex" (regex-base)

description:
    This package provides a pure Haskell \"Tagged\" DFA regex engine for <//hackage.haskell.org/package/regex-base regex-base>. This implementation was inspired by the algorithm (and Master'\''s thesis) behind the regular expression library known as <https://github.com/laurikari/tre/ TRE or libtre>.

    Please consult the "Text.Regex.TDFA" module for API documentation including a tutorial with usage examples;
    see also <https://wiki.haskell.org/Regular_expressions> for general information about regular expression support in Haskell.

category:             Text
abi:                  645363abf41d00892aaeadcc58c70466
exposed:              True
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.NewDFA.Tester Text.Regex.TDFA.NewDFA.Uncons
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA Text.Regex.TDFA.Text
    Text.Regex.TDFA.Text.Lazy

hidden-modules:       Paths_regex_tdfa
import-dirs:          /usr/lib/ghc-9.4.8/site-local/regex-tdfa-1.3.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/regex-tdfa-1.3.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/regex-tdfa-1.3.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-tdfa
hs-libraries:         HSregex-tdfa-1.3.2.3-2vpgF9jiCYzHaZRZi6jkOP
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    mtl-2.2.2 parsec-3.1.16.1
    regex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html:         /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-tdfa-1.3.2.4-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-tdfa
version:              1.3.2.4
visibility:           public
id:                   regex-tdfa-1.3.2.4-4spaPYpacr92ooLlQb3epN
key:                  regex-tdfa-1.3.2.4-4spaPYpacr92ooLlQb3epN
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2009, Christopher Kuklewicz
maintainer:           Andreas Abel
author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:
    Pure Haskell Tagged DFA Backend for "Text.Regex" (regex-base)

description:
    This package provides a pure Haskell \"Tagged\" DFA regex engine for <//hackage.haskell.org/package/regex-base regex-base>. This implementation was inspired by the algorithm (and Master'\''s thesis) behind the regular expression library known as <https://github.com/laurikari/tre/ TRE or libtre>.

    Please consult the "Text.Regex.TDFA" module for API documentation including a tutorial with usage examples;
    see also <https://wiki.haskell.org/Regular_expressions> for general information about regular expression support in Haskell.

category:             Text
abi:                  3b9c6429c6213fc46d35409530030585
exposed:              True
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.NewDFA.Tester Text.Regex.TDFA.NewDFA.Uncons
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA Text.Regex.TDFA.Text
    Text.Regex.TDFA.Text.Lazy

hidden-modules:       Paths_regex_tdfa
import-dirs:          /usr/lib/ghc-9.4.8/site-local/regex-tdfa-1.3.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/regex-tdfa-1.3.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/regex-tdfa-1.3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-tdfa
hs-libraries:         HSregex-tdfa-1.3.2.4-4spaPYpacr92ooLlQb3epN
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    mtl-2.2.2 parsec-3.1.16.1
    regex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html:         /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
